==> nextcloud-app-deck-1%3A1.15.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "%s on %s" : "%s në %s",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "Done" : "Përfunduar",
    "Attachments" : "Bashkangjitjet",
    "File" : "Skedar ",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Cancel" : "Anullo",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Add card" : "Shto kartë",
    "Completed" : "Të plotësuara",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Open details" : "Hapni detajet",
    "Details" : "Detajet",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Activity" : "Aktiviteti",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Owner" : "Zotëruesi",
    "Delete" : "Delete",
    "Edit" : "Edito",
    "Members" : "Anëtar",
    "Download" : "Shkarko",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Comments" : "Komentet",
    "Save" : "Ruaj",
    "Created:" : "Krijuar:",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "Select Date" : "Zgjidhni Datën",
    "Remove due date" : "Hiq datën e mbarimit",
    "(group)" : "(grup)",
    "seconds ago" : "sekonda më parë",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Action" : "Veprim",
    "Search" : "Kërko",
    "Archived boards" : "Borde të arkivuara",
    "Shared with you" : "E ndarë me ju",
    "Board details" : "Detajet e Tabeles ",
    "Edit board" : "Tabela e editimeve",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Archive board" : "Arkivo bordin",
    "No notifications" : "Asnjë njofim",
    "Delete board" : "Fshij bordin",
    "Advanced options" : "Opsione të avancuara",
    "Export" : "Eksport",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "Close" : "Mbylleni",
    "Due date" : "Data e vendosur",
    "Share" : "Shpërndaje",
    "Personal" : "Personale",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.16.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "%s on %s" : "%s në %s",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "Done" : "Përfunduar",
    "Attachments" : "Bashkangjitjet",
    "File" : "Skedar ",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Cancel" : "Anullo",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Add card" : "Shto kartë",
    "Completed" : "Të plotësuara",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Open details" : "Hapni detajet",
    "Details" : "Detajet",
    "General" : "Të përgjithshme",
    "Search" : "Kërko",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Activity" : "Aktiviteti",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Owner" : "Zotëruesi",
    "Delete" : "Delete",
    "Edit" : "Edito",
    "Members" : "Anëtar",
    "Download" : "Shkarko",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Comments" : "Komentet",
    "Save" : "Ruaj",
    "Created:" : "Krijuar:",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "Select Date" : "Zgjidhni Datën",
    "Remove due date" : "Hiq datën e mbarimit",
    "(group)" : "(grup)",
    "seconds ago" : "sekonda më parë",
    "Archived boards" : "Borde të arkivuara",
    "Shared with you" : "E ndarë me ju",
    "Board details" : "Detajet e Tabeles ",
    "Edit board" : "Tabela e editimeve",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Archive board" : "Arkivo bordin",
    "No notifications" : "Asnjë njofim",
    "Delete board" : "Fshij bordin",
    "Advanced options" : "Opsione të avancuara",
    "Export" : "Eksport",
    "Close" : "Mbylleni",
    "Due date" : "Data e vendosur",
    "Share" : "Shpërndaje",
    "Personal" : "Personale",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Keyboard shortcut" : "Shkurtore tastiere",
    "Action" : "Veprim",
    "Today" : "Sot",
    "Tomorrow" : "Nesër"
},
"nplurals=2; plural=(n != 1);");
